@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.5.1.  */
+/* A Bison parser, made by GNU Bison 3.8.2.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
    Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -16,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -31,8 +31,9 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-/* Undocumented macros, especially those whose name start with YY_,
-   are private implementation details.  Do not rely on them.  */
+/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
+   especially those whose name start with YY_ or yy_.  They are
+   private implementation details that can be changed or removed.  */
 
 #ifndef YY_YY_GRAMMAR_H_INCLUDED
 # define YY_YY_GRAMMAR_H_INCLUDED
@@ -44,62 +45,71 @@
 extern int yydebug;
 #endif
 
-/* Token type.  */
+/* Token kinds.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
   enum yytokentype
   {
-    NAME = 258,
-    FUNC = 259,
-    BEGINOBJ = 260,
-    ENDOBJ = 261,
-    BEGIN_INCLUDE = 262,
-    BEGIN_ACTION = 263,
-    BEGIN_PROPERTY = 264,
-    BEGIN_CONSTANT = 265,
-    BEGIN_TPL = 266,
-    BEGIN_RULESET = 267,
-    STOP = 268,
-    SET = 269,
-    RESET = 270,
-    UNSET = 271,
-    CONTINUE = 272,
-    EXISTS = 273,
-    CALL = 274,
-    CALL_INDIRECT = 275,
-    LEGACY_ACTION = 276,
-    LEGACY_RULESET = 277,
-    PRIFILT = 278,
-    PROPFILT = 279,
-    BSD_TAG_SELECTOR = 280,
-    BSD_HOST_SELECTOR = 281,
-    RELOAD_LOOKUP_TABLE_PROCEDURE = 282,
-    IF = 283,
-    THEN = 284,
-    ELSE = 285,
-    FOREACH = 286,
-    ITERATOR_ASSIGNMENT = 287,
-    DO = 288,
-    OR = 289,
-    AND = 290,
-    NOT = 291,
-    VAR = 292,
-    STRING = 293,
-    NUMBER = 294,
-    CMP_EQ = 295,
-    CMP_NE = 296,
-    CMP_LE = 297,
-    CMP_GE = 298,
-    CMP_LT = 299,
-    CMP_GT = 300,
-    CMP_CONTAINS = 301,
-    CMP_CONTAINSI = 302,
-    CMP_STARTSWITH = 303,
-    CMP_STARTSWITHI = 304,
-    UMINUS = 305
+    YYEMPTY = -2,
+    YYEOF = 0,                     /* "end of file"  */
+    YYerror = 256,                 /* error  */
+    YYUNDEF = 257,                 /* "invalid token"  */
+    NAME = 258,                    /* NAME  */
+    FUNC = 259,                    /* FUNC  */
+    BEGINOBJ = 260,                /* BEGINOBJ  */
+    ENDOBJ = 261,                  /* ENDOBJ  */
+    BEGIN_INCLUDE = 262,           /* BEGIN_INCLUDE  */
+    BEGIN_ACTION = 263,            /* BEGIN_ACTION  */
+    BEGIN_PROPERTY = 264,          /* BEGIN_PROPERTY  */
+    BEGIN_CONSTANT = 265,          /* BEGIN_CONSTANT  */
+    BEGIN_TPL = 266,               /* BEGIN_TPL  */
+    BEGIN_RULESET = 267,           /* BEGIN_RULESET  */
+    STOP = 268,                    /* STOP  */
+    SET = 269,                     /* SET  */
+    RESET = 270,                   /* RESET  */
+    UNSET = 271,                   /* UNSET  */
+    CONTINUE = 272,                /* CONTINUE  */
+    EXISTS = 273,                  /* EXISTS  */
+    CALL = 274,                    /* CALL  */
+    CALL_INDIRECT = 275,           /* CALL_INDIRECT  */
+    LEGACY_ACTION = 276,           /* LEGACY_ACTION  */
+    LEGACY_RULESET = 277,          /* LEGACY_RULESET  */
+    PRIFILT = 278,                 /* PRIFILT  */
+    PROPFILT = 279,                /* PROPFILT  */
+    BSD_TAG_SELECTOR = 280,        /* BSD_TAG_SELECTOR  */
+    BSD_HOST_SELECTOR = 281,       /* BSD_HOST_SELECTOR  */
+    RELOAD_LOOKUP_TABLE_PROCEDURE = 282, /* RELOAD_LOOKUP_TABLE_PROCEDURE  */
+    IF = 283,                      /* IF  */
+    THEN = 284,                    /* THEN  */
+    ELSE = 285,                    /* ELSE  */
+    FOREACH = 286,                 /* FOREACH  */
+    ITERATOR_ASSIGNMENT = 287,     /* ITERATOR_ASSIGNMENT  */
+    DO = 288,                      /* DO  */
+    OR = 289,                      /* OR  */
+    AND = 290,                     /* AND  */
+    NOT = 291,                     /* NOT  */
+    VAR = 292,                     /* VAR  */
+    STRING = 293,                  /* STRING  */
+    NUMBER = 294,                  /* NUMBER  */
+    CMP_EQ = 295,                  /* CMP_EQ  */
+    CMP_NE = 296,                  /* CMP_NE  */
+    CMP_LE = 297,                  /* CMP_LE  */
+    CMP_GE = 298,                  /* CMP_GE  */
+    CMP_LT = 299,                  /* CMP_LT  */
+    CMP_GT = 300,                  /* CMP_GT  */
+    CMP_CONTAINS = 301,            /* CMP_CONTAINS  */
+    CMP_CONTAINSI = 302,           /* CMP_CONTAINSI  */
+    CMP_STARTSWITH = 303,          /* CMP_STARTSWITH  */
+    CMP_STARTSWITHI = 304,         /* CMP_STARTSWITHI  */
+    UMINUS = 305                   /* UMINUS  */
   };
+  typedef enum yytokentype yytoken_kind_t;
 #endif
-/* Tokens.  */
+/* Token kinds.  */
+#define YYEMPTY -2
+#define YYEOF 0
+#define YYerror 256
+#define YYUNDEF 257
 #define NAME 258
 #define FUNC 259
 #define BEGINOBJ 260
@@ -170,7 +180,7 @@ union YYSTYPE
 	struct cnffparamlst *fparams;
 	struct cnfitr *itr;
 
-#line 174 "grammar.h"
+#line 184 "grammar.h"
 
 };
 typedef union YYSTYPE YYSTYPE;
@@ -181,6 +191,8 @@ typedef union YYSTYPE YYSTYPE;
 
 extern YYSTYPE yylval;
 
+
 int yyparse (void);
 
+
 #endif /* !YY_YY_GRAMMAR_H_INCLUDED  */
