@@ -19,7 +19,7 @@
 #ifndef PARSERIF_H_DEFINED
 #define PARSERIF_H_DEFINED
 #include "rainerscript.h"
-int cnfSetLexFile(char*);
+int cnfSetLexFile(const char*);
 void parser_errmsg(const char *fmt, ...) __attribute__((format(printf, 1, 2)));
 void parser_warnmsg(const char *fmt, ...) __attribute__((format(printf, 1, 2)));
 void tellLexEndParsing(void);
@@ -28,6 +28,7 @@ int yyparse(void);
 extern int yydebug;
 extern int yylineno;
 extern char *cnfcurrfn;
+extern FILE *fp_rs_full_conf_output;
 #endif
 
 /* entry points to be called after the parser has processed the
