@@ -1968,7 +1968,7 @@ GetRemoteIP(nsd_t *pNsd, prop_t **ip)
  * rgerhards, 2008-04-25
  */
 static rsRetVal
-AcceptConnReq(nsd_t *pNsd, nsd_t **ppNew)
+AcceptConnReq(nsd_t *pNsd, nsd_t **ppNew, char *const connInfo)
 {
 	DEFiRet;
 	int gnuRet;
@@ -1979,7 +1979,8 @@ AcceptConnReq(nsd_t *pNsd, nsd_t **ppNew)
 	ISOBJ_TYPE_assert((pThis), nsd_gtls);
 	CHKiRet(nsd_gtlsConstruct(&pNew)); // TODO: prevent construct/destruct!
 	CHKiRet(nsd_ptcp.Destruct(&pNew->pTcp));
-	CHKiRet(nsd_ptcp.AcceptConnReq(pThis->pTcp, &pNew->pTcp));
+	CHKiRet(nsd_ptcp.AcceptConnReq(pThis->pTcp, &pNew->pTcp, connInfo));
+
 
 	if(pThis->iMode == 0) {
 		/* we are in non-TLS mode, so we are done */
@@ -2069,9 +2070,9 @@ AcceptConnReq(nsd_t *pNsd, nsd_t **ppNew)
 
 finalize_it:
 	if(iRet != RS_RET_OK) {
-if (error_position != NULL) {
-	dbgprintf("AcceptConnReq error_position=%s\n", error_position);
-}
+		if (error_position != NULL) {
+			dbgprintf("AcceptConnReq error_position=%s\n", error_position);
+		}
 
 		if(pNew != NULL)
 			nsd_gtlsDestruct(&pNew);
