@@ -112,7 +112,9 @@ typedef struct lookup_string_tab_s lookup_string_tab_t;
 typedef struct lookup_array_tab_s lookup_array_tab_t;
 typedef struct lookup_sparseArray_tab_s lookup_sparseArray_tab_t;
 typedef struct lookup_sparseArray_tab_entry_s lookup_sparseArray_tab_entry_t;
+typedef struct lookup_regex_tab_entry_s lookup_regex_tab_entry_t;
 typedef struct lookup_tables_s lookup_tables_t;
+typedef struct lookup_regex_tab_s lookup_regex_tab_t;
 typedef union lookup_key_u lookup_key_t;
 
 typedef struct lookup_s lookup_t;
